//
//  lph7366.c
//  Graphic LCD module "LPH7366" I/O library
//  Copyright(C)2012-2015 Toyohiko Togashi tog001@nifty.com
//
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//    Update history
//    ---------- ----- -------------------------------------------
//    2012.04.08 v0.0  First cording
//    2012.04.18 v0.1  Bug fix, '\r' function
//    2012.05.07 v0.2  Bug fix, Case x-position == screen column is blank line
//    2012.05.07 v0.2  Reverse function character '\002','\003'
//    2015.01.19 v0.3  New API lcd_power(),lcd_contrast(),lcd_draw_image()
//

#include <avr/io.h>						// WinAVR library
#include <avr/pgmspace.h>				// Flash access
#include <avr/interrupt.h>				// 
#include <util/delay.h>					// 

#include "lph7366.h"					//

//
//	Instance variable
//
#define LCD_DRAW_OPT_REV	0x01		// ADD 2012.05.07
unsigned char 	lcd_draw_opt = 0x00;	// ADD 2012.05.07
#ifdef LCD_VCD
unsigned char	lcd_vcd_x1 = 0;
unsigned char	lcd_vcd_y1 = 0;
unsigned char	lcd_vcd_x2 = LCD_SCREEN_WIDTH  - LCD_FONT_WIDTH  + 1;
unsigned char	lcd_vcd_y2 = LCD_SCREEN_HEIGHT - LCD_FONT_HEIGHT + 1;
unsigned char	lcd_vcd_w  = LCD_SCREEN_WIDTH;
unsigned char	lcd_vcd_h  = LCD_SCREEN_HEIGHT;
unsigned char	lcd_curs_x = 0;
unsigned char	lcd_curs_y = 0;
#endif

//
// 	Port I/O
//
void lcd_sendCmdData(unsigned char dc, unsigned char data) {
	unsigned char	i;
//	unsigned char	s;

//	s = SREG;
//	cli();

	LCD_PIN_SCLK_OFF();
	LCD_PIN_SCE_ON();

	if (dc) {
		LCD_PIN_DC_ON();
	} else {
		LCD_PIN_DC_OFF();
	}
	for(i = 0; i < 8; i++) {
		if (data & 0x80) {
			LCD_PIN_SDIN_ON();
		} else {
			LCD_PIN_SDIN_OFF();
		}
		LCD_PIN_SCLK_ON();
		LCD_PIN_SCLK_OFF();
		data = data << 1;
	}

	LCD_PIN_SCE_OFF();

//	if (s & _BV(SREG_I)) {				// Resume global interrupt
//		sei();
//	}

	return;
}


//
//	Open
//
void lcd_start(void) {
	LCD_PIN_SCLK_INIT();
	LCD_PIN_SDIN_INIT();
	LCD_PIN_DC_INIT();
	LCD_PIN_SCE_INIT();
#ifdef LCD_PIN_RESET_INIT
	LCD_PIN_RES_INIT();
#endif
	return;
}
										// ADD START 2015.01.19
void lcd_power(unsigned char mode) {
	switch(mode) {
	case LCD_POWER_MODE_NORMAL:
		lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_B);
		break;
	case LCD_POWER_MODE_SLEEP:
		lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_B | LCD_CMD_FUNC_PD);
		break;
	default:
		break;
	}
	return;
}
										// ADD END 2015.01.19
void lcd_init(void) {

	// Reset sequence
#ifdef LCD_PIN_RES_ON
	LCD_PIN_RES_ON();
	_delay_ms(1);
#endif
#ifdef LCD_PIN_RES_OFF
	LCD_PIN_RES_OFF();
	_delay_ms(1);
#endif

	// Init code
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_H);	// Extend instruction set
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_H_TEMP | 0);			// ADD 2015.01.19
//	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_H_BIAS | 4);			// ADD 2015.01.19
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_H_BIAS | 3);			// ADD 2015.01.19
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_H_VOP  | 63);			// ADD 2015.01.19
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_B);	// Basic instruction set
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_NORMAL);

	// Screen clear
	lcd_control(LCD_DISP_CLEAR_HOME);

	return;
}

//
//	Close
//
void lcd_stop(void) {
#ifdef LCD_PIN_RES_TERM
	LCD_PIN_RES_TERM();
#else
	// Power down mode
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_PD);
#endif
	LCD_PIN_SCE_TERM();
	LCD_PIN_DC_TERM();
	LCD_PIN_SDIN_TERM();
	LCD_PIN_SCLK_TERM();
	return;
}

										// ADD START 2015.01.19
//
//	Set a display contrast
//
extern void lcd_contrast(unsigned char level){
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_H);	// Extend instruction set
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_H_VOP  | (level & 0x7f));// darkness
//	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_H_BIAS | (level & 0x07));// darkness
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_FUNC | LCD_CMD_FUNC_B);	// Basic instruction set
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_NORMAL);
	return;
}
										// ADD END 2015.01.19

//
//	Rectangle
//


//
//	Line
//


//										// ADD START 2015.01.19
//	Bit image
//
void lcd_draw_image(unsigned char x, unsigned char y, unsigned char *b, unsigned char len) {

	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_XADDR | x);
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_YADDR | (y >> 3));
	for(; len > 0; --len) {
		unsigned char	f;
		
		f = *b++;
		if (lcd_draw_opt & LCD_DRAW_OPT_REV) {
			f = ~f;
		}
		lcd_sendCmdData(LCD_DC_DATA, f);
	}
	return;
}
// ADD END 2015.01.19


//
//	Character font
//
//const prog_uchar	lcd_font5x7[][LCD_FONT_WIDTH] = {			// DEL 2015.01.19
const unsigned char PROGMEM	lcd_font5x7[][LCD_FONT_WIDTH] = {	// ADD 2015.01.19
	{0b00000000,	// " "
	 0b00000000,
	 0b00000000,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// !
	 0b00000000,
	 0b01011111,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// "
	 0b00000011,
	 0b00000000,
	 0b00000011,
	 0b00000000},
	{0b00010100,	// #
	 0b00111110,
	 0b00010100,
	 0b00111110,
	 0b00010100},
	{0b00100100,	// $
	 0b00101010,
	 0b01111111,
	 0b00101010,
	 0b00010010},
	{0b01100010,	// %
	 0b00010101,
	 0b00101010,
	 0b01010100,
	 0b00100011},
	{0b00110110,	// &
	 0b01001001,
	 0b01010101,
	 0b00100010,
	 0b01010000},
	{0b00000000,	// '
	 0b00000100,
	 0b00000011,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// (
	 0b00000000,
	 0b00011100,
	 0b01100011,
	 0b00000000},
	{0b00000000,	// )
	 0b01100011,
	 0b00011100,
	 0b00000000,
	 0b00000000},
	{0b00010100,	// *
	 0b00001000,
	 0b00111110,
	 0b00001000,
	 0b00010100},
	{0b00001000,	// +
	 0b00001000,
	 0b00111110,
	 0b00001000,
	 0b00001000},
	{0b00000000,	// ,
	 0b10100000,
	 0b01100000,
	 0b00000000,
	 0b00000000},
	{0b00001000,	// -
	 0b00001000,
	 0b00001000,
	 0b00001000,
	 0b00001000},
	{0b00000000,	// .
	 0b01100000,
	 0b01100000,
	 0b00000000,
	 0b00000000},
	{0b00100000,	// /
	 0b00010000,
	 0b00001000,
	 0b00000100,
	 0b00000010},
	{0b00011100,	// 0
	 0b00100010,
	 0b01000001,
	 0b00100010,
	 0b00011100},
	{0b00000000,	// 1
	 0b00000010,
	 0b01111111,
	 0b00000000,
	 0b00000000},
	{0b01000010,	// 2
	 0b01100001,
	 0b01010001,
	 0b01001001,
	 0b01000110},
	{0b00100010,	// 3
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00110110},
	{0b00111000,	// 4
	 0b00100100,
	 0b00100010,
	 0b01111111,
	 0b00100000},
	{0b00101111,	// 5
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00110001},
	{0b00111110,	// 6
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00110010},
	{0b00000001,	// 7
	 0b01000001,
	 0b00110001,
	 0b00001101,
	 0b00000011},
	{0b00110110,	// 8
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00110110},
	{0b01000110,	// 9
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00111110},
	{0b00000000,	// :
	 0b00000000,
	 0b00100100,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// ;
	 0b01000000,
	 0b00100100,
	 0b00000000,
	 0b00000000},
	{0b00001000,	// <
	 0b00010100,
	 0b00100010,
	 0b01000001,
	 0b00000000},
	{0b00010100,	// =
	 0b00010100,
	 0b00010100,
	 0b00010100,
	 0b00010100},
	{0b00000000,	// >
	 0b01000001,
	 0b00100010,
	 0b00010100,
	 0b00001000},
	{0b00000010,	// ?
	 0b00000001,
	 0b01010001,
	 0b00001001,
	 0b00000110},
	{0b00110110,	// @
	 0b01001001,
	 0b01110001,
	 0b01000001,
	 0b00111110},
	{0b01111100,	// A
	 0b00010010,
	 0b00010001,
	 0b00010010,
	 0b01111100},
	{0b01111111,	// B
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00110110},
	{0b00111110,	// C
	 0b01000001,
	 0b01000001,
	 0b01000001,
	 0b00100010},
	{0b01111111,	// D
	 0b01000001,
	 0b01000001,
	 0b01000001,
	 0b00111110},
	{0b01111111,	// E
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b01000001},
	{0b01111111,	// F
	 0b00001001,
	 0b00001001,
	 0b00001001,
	 0b00001001},
	{0b00111110,	// G
	 0b01000001,
	 0b01001001,
	 0b00101001,
	 0b01111010},
	{0b01111111,	// H
	 0b00001000,
	 0b00001000,
	 0b00001000,
	 0b01111111},
	{0b00000000,	// I
	 0b01000001,
	 0b01111111,
	 0b01000001,
	 0b00000000},
	{0b01000000,	// J
	 0b01000000,
	 0b00111111,
	 0b00000000,
	 0b00000000},
	{0b01111111,	// K
	 0b00001000,
	 0b00010100,
	 0b00100010,
	 0b01000001},
	{0b01111111,	// L
	 0b01000000,
	 0b01000000,
	 0b01000000,
	 0b01000000},
	{0b01111111,	// M
	 0b00000010,
	 0b00000100,
	 0b00000010,
	 0b01111111},
	{0b01111111,	// N
	 0b00000110,
	 0b00001000,
	 0b00110000,
	 0b01111111},
	{0b00111110,	// O
	 0b01000001,
	 0b01000001,
	 0b01000001,
	 0b00111110},
	{0b01111111,	// P
	 0b00010001,
	 0b00010001,
	 0b00010001,
	 0b00001110},
	{0b00111110,	// Q
	 0b01000001,
	 0b01010001,
	 0b01100001,
	 0b01111110},
	{0b01111111,	// R
	 0b00010001,
	 0b00010001,
	 0b00110001,
	 0b01001110},
	{0b00100110,	// S
	 0b01001001,
	 0b01001001,
	 0b01001001,
	 0b00110010},
	{0b00000001,	// T
	 0b00000001,
	 0b01111111,
	 0b00000001,
	 0b00000001},
	{0b00111111,	// U
	 0b01000000,
	 0b01000000,
	 0b01000000,
	 0b00111111},
	{0b00011111,	// V
	 0b00100000,
	 0b01000000,
	 0b00100000,
	 0b00011111},
	{0b01111111,	// W
	 0b00100000,
	 0b00010000,
	 0b00100000,
	 0b01111111},
	{0b01100011,	// X
	 0b00010100,
	 0b00001000,
	 0b00010100,
	 0b01100011},
	{0b00000001,	// Y
	 0b00000010,
	 0b01111100,
	 0b00000010,
	 0b00000001},
	{0b01100001,	// Z
	 0b01010001,
	 0b01001001,
	 0b01000101,
	 0b01000011},
	{0b00000000,	// [
	 0b00000000,
	 0b01111111,
	 0b01000001,
	 0b00000000},
	{0b00000010,	// /
	 0b00000100,
	 0b00001000,
	 0b00010000,
	 0b00100000},
	{0b00000000,	// ]
	 0b01000001,
	 0b01111111,
	 0b00000000,
	 0b00000000},
	{0b00000100,	// ^
	 0b00000010,
	 0b00000001,
	 0b00000010,
	 0b00000100},
	{0b01000000,	// _
	 0b01000000,
	 0b01000000,
	 0b01000000,
	 0b01000000},
	{0b00000000,	// `
	 0b00000001,
	 0b00000010,
	 0b00000000,
	 0b00000000},
	{0b00110100,	// a
	 0b01001010,
	 0b01001010,
	 0b00101010,
	 0b01111100},
	{0b01111111,	// b
	 0b01001000,
	 0b01001000,
	 0b01001000,
	 0b00110000},
	{0b00111000,	// c
	 0b01000100,
	 0b01000100,
	 0b01000100,
	 0b00101000},
	{0b00110000,	// d
	 0b01001000,
	 0b01001000,
	 0b01001000,
	 0b01111111},
	{0b00111000,	// e
	 0b01010100,
	 0b01010100,
	 0b01010100,
	 0b01011000},
	{0b00000000,	// f
	 0b00001000,
	 0b01111110,
	 0b00001001,
	 0b00000000},
	{0b10011000,	// g
	 0b10100100,
	 0b10100100,
	 0b10100100,
	 0b01111000},
	{0b01111111,	// h
	 0b00001000,
	 0b00001000,
	 0b00001000,
	 0b01110000},
	{0b00000000,	// i
	 0b00000000,
	 0b01111101,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// j
	 0b10000000,
	 0b01111101,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// k
	 0b01111111,
	 0b00100000,
	 0b00110000,
	 0b01001000},
	{0b00000000,	// l
	 0b00000000,
	 0b01111111,
	 0b01000000,
	 0b00000000},
	{0b01111000,	// m
	 0b00000100,
	 0b01111000,
	 0b00000100,
	 0b01111000},
	{0b01111100,	// n
	 0b00001000,
	 0b00000100,
	 0b00000100,
	 0b01111000},
	{0b00111000,	// o
	 0b01000100,
	 0b01000100,
	 0b01000100,
	 0b00111000},
	{0b11111100,	// p
	 0b00100100,
	 0b00100100,
	 0b00100100,
	 0b00011000},
	{0b00011000,	// q
	 0b00100100,
	 0b00100100,
	 0b00100100,
	 0b11111100},
	{0b01111100,	// r
	 0b00001000,
	 0b00000100,
	 0b00000100,
	 0b00000100},
	{0b01001000,	// s
	 0b01010100,
	 0b01010100,
	 0b01010100,
	 0b00100100},
	{0b00000000,	// t
	 0b00000100,
	 0b00111111,
	 0b01000100,
	 0b00000000},
	{0b00111100,	// u
	 0b01000000,
	 0b01000000,
	 0b01000000,
	 0b00111100},
	{0b00011100,	// v
	 0b00100000,
	 0b01000000,
	 0b00100000,
	 0b00011100},
	{0b00111100,	// w
	 0b01000000,
	 0b00111100,
	 0b01000000,
	 0b00111100},
	{0b01000100,	// x
	 0b00101000,
	 0b00010000,
	 0b00101000,
	 0b01000100},
	{0b10001100,	// y
	 0b01010000,
	 0b00100000,
	 0b00010000,
	 0b00001100},
	{0b01000100,	// z
	 0b01100100,
	 0b01010100,
	 0b01001100,
	 0b01000100},
	{0b00000000,	// {
	 0b00001000,
	 0b00110110,
	 0b01000001,
	 0b00000000},
	{0b00000000,	// |
	 0b00000000,
	 0b11111111,
	 0b00000000,
	 0b00000000},
	{0b00000000,	// }
	 0b01000001,
	 0b00110110,
	 0b00001000,
	 0b00000000},
	{0b00000010,	// ~
	 0b00000001,
	 0b00000010,
	 0b00000100,
	 0b00000010},
	{0b11111111,	// XX
	 0b11111111,
	 0b11111111,
	 0b11111111,
	 0b11111111,
	 0b11111111}
};

//
//	Text
//
void lcd_draw_char(unsigned char x, unsigned char y, char c) {
	unsigned char	i;

//	if ((x <= (LCD_SCREEN_WIDTH - LCD_FONT_WIDTH) &&
//	    (y <= (LCD_SCREEN_HEIGHT - LCD_FONT_HEIGHT)) {
//	}
	c &= 0x7f;
	c -= ' ';

	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_XADDR | x);
	lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_YADDR | (y >> 3));
	for(i = 0; i < LCD_FONT_WIDTH; i++) {
		unsigned char	f;						// ADD 2012.05.07
												// ADD 2012.05.07
//		f = pgm_read_byte(&lcd_font5x7[c][i]);	// ADD 2012.05.07  DEL 2015.01.19
		f = pgm_read_byte(&lcd_font5x7[(unsigned char)c][i]);	// ADD 2015.01.19
		if (lcd_draw_opt & LCD_DRAW_OPT_REV) {	// ADD 2012.05.07
			f = ~f;								// ADD 2012.05.07
		}										// ADD 2012.05.07
		lcd_sendCmdData(LCD_DC_DATA, f);		// ADD 2012.05.07

//		lcd_sendCmdData(LCD_DC_DATA, pgm_read_byte(&lcd_font5x7[c][i]));	// DEL 2012.05.07
	}
	return;
}

void lcd_draw_str(
	unsigned char	sx,					// Upper right position
	unsigned char	sy,					//
	char			*str				// '\0' terminated text
) {
	unsigned char	x;
	unsigned char	y;
	char			c;

	x  = sx;
	y  = sy;

	while((c = *str++) != '\0') {

		c &= 0b01111111;

		// Visual char
		if (c >= ' ') {

			// Screen range out										// ADD 2012.05.07
			if (x >= (LCD_SCREEN_WIDTH - LCD_FONT_WIDTH + 1)) {		// ADD 2012.05.07
				x = sx;												// ADD 2012.05.07
				y += LCD_FONT_HEIGHT;								// ADD 2012.05.07
			}														// ADD 2012.05.07
			if (y >= (LCD_SCREEN_HEIGHT - LCD_FONT_HEIGHT + 1)) {	// ADD 2012.05.07
				y = 0;												// ADD 2012.05.07
			}														// ADD 2012.05.07

			lcd_draw_char(x, y, c);
			x += LCD_FONT_WIDTH;

		// CLF
		} else if (c == '\n') {
			x = sx;
			y += LCD_FONT_HEIGHT;

		// CR
		} else if (c == '\r') {
			y += LCD_FONT_HEIGHT;
		}

//		// Screen range out											// DEL 2012.05.07
//		if (x >= (LCD_SCREEN_WIDTH - LCD_FONT_WIDTH + 1)) {			// DEL 2012.05.07
//			x = sx;													// DEL 2012.05.07
//			y += LCD_FONT_HEIGHT;									// DEL 2012.05.07
//		}															// DEL 2012.05.07
//		if (y >= (LCD_SCREEN_HEIGHT - LCD_FONT_HEIGHT + 1)) {		// DEL 2012.05.07
//			y = 0;													// DEL 2012.05.07
//		}															// DEL 2012.05.07
	}

	return;
}


//
//	Virtual character display interfaces
//
#ifdef LCD_VCD

void lcd_setViewPort(unsigned char	x, unsigned char y, unsigned char w, unsigned char h) {
	lcd_vcd_x1 = x;
	lcd_vcd_y1 = y;
	lcd_vcd_x2 = x + w - LCD_FONT_WIDTH  + 1;
	lcd_vcd_y2 = y + h - LCD_FONT_HEIGHT + 1;
	lcd_vcd_w  = w;
	lcd_vcd_h  = h;
	lcd_curs_x = x;
	lcd_curs_y = y;
	return;
}

void lcd_position(unsigned char	column, unsigned char row) {
	lcd_curs_x = column * LCD_FONT_WIDTH  + lcd_vcd_x1;
	lcd_curs_y = row    * LCD_FONT_HEIGHT + lcd_vcd_y1;
	return;
}

void lcd_prString(char *str) {
	char	c;

	while((c = *str++) != '\0') {

		c &= 0b01111111;

		// Visual char
		if (c >= ' ') {

			// View range out					// ADD 2012.05.07
			if (lcd_curs_x >= lcd_vcd_x2) {		// ADD 2012.05.07
				lcd_curs_x = lcd_vcd_x1;		// ADD 2012.05.07
				lcd_curs_y += LCD_FONT_HEIGHT;	// ADD 2012.05.07
			}									// ADD 2012.05.07
			if (lcd_curs_y >= lcd_vcd_y2) {		// ADD 2012.05.07
				lcd_curs_y = lcd_vcd_y1;		// ADD 2012.05.07
			}									// ADD 2012.05.07

			lcd_draw_char(lcd_curs_x, lcd_curs_y, c);
			lcd_curs_x += LCD_FONT_WIDTH;

		// LF
		} else if (c == '\n') {
			lcd_curs_x = lcd_vcd_x1;
			lcd_curs_y += LCD_FONT_HEIGHT;

		// CR
		} else if (c == '\r') {
			lcd_curs_x = lcd_vcd_x1;			// ADD 2012.04.18
//			lcd_curs_y += LCD_FONT_HEIGHT;		// DEL 2012.04.18

		// FF
		} else if (c == '\f') {
			lcd_control(LCD_DISP_CLEAR_HOME);

		// VT
		} else if (c == '\v') {
			lcd_control(LCD_CURSOR_HOME);

		// STX Start reverse					// ADD 2012.05.07
		} else if (c == '\002') {				// ADD 2012.05.07
			lcd_draw_opt |= LCD_DRAW_OPT_REV;	// ADD 2012.05.07
												// ADD 2012.05.07
		// ETX Stop reverse						// ADD 2012.05.07
		} else if (c == '\003') {				// ADD 2012.05.07
			lcd_draw_opt &= ~LCD_DRAW_OPT_REV;	// ADD 2012.05.07
		}

//		// View range out						// DEL 2012.05.07
//		if (lcd_curs_x >= lcd_vcd_x2) {			// DEL 2012.05.07
//			lcd_curs_x = lcd_vcd_x1;			// DEL 2012.05.07
//			lcd_curs_y += LCD_FONT_HEIGHT;		// DEL 2012.05.07
//		}										// DEL 2012.05.07
//		if (lcd_curs_y >= lcd_vcd_y2) {			// DEL 2012.05.07
//			lcd_curs_y = lcd_vcd_y1;			// DEL 2012.05.07
//		}										// DEL 2012.05.07
	}

	return;
}

void lcd_control(unsigned char cmd) {
	int i;

	switch(cmd) {
	case LCD_DISP_CLEAR_HOME:
		for(i = 0; i < (LCD_SCREEN_WIDTH * LCD_SCREEN_HEIGHT / 8); i++) {
			lcd_sendCmdData(LCD_DC_DATA, 0);
		}
	case LCD_CURSOR_HOME:
		lcd_curs_x = lcd_vcd_x1;
		lcd_curs_y = lcd_vcd_y1;
		break;
	case LCD_DISP_ON:
		lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_NORMAL);
		break;
	case LCD_DISP_OFF:
		lcd_sendCmdData(LCD_DC_COMMAND, LCD_CMD_B_BLANK);
		break;
	default:
		break;
	}
	return;
}

#endif	// LCD_VCD


